@@ -72,6 +72,7 @@ class MockedDatetime(datetime):
 
 skip_reason = skip_docs_tests()
 LINE_LENGTH = 80
+TARGET_VERSION = 'py39'
 
 
 def print_callback(print_statement: str) -> str:
@@ -95,11 +96,23 @@ def run_example(example: CodeExample, eval_example: EvalExample, mocker: Any) ->
 
     group_name = prefix_settings.get('group')
 
-    eval_example.set_config(ruff_ignore=['D', 'T', 'E721', 'Q001'], line_length=LINE_LENGTH)
+    eval_example.set_config(
+        ruff_ignore=['D', 'T', 'B', 'C4', 'E721', 'Q001', 'PERF', 'PIE790'],
+        line_length=LINE_LENGTH,
+        target_version=TARGET_VERSION,
+    )
     if '# ignore-above' in example.source:
-        eval_example.set_config(ruff_ignore=eval_example.config.ruff_ignore + ['E402'], line_length=LINE_LENGTH)
+        eval_example.set_config(
+            ruff_ignore=eval_example.config.ruff_ignore + ['E402'],
+            line_length=LINE_LENGTH,
+            target_version=TARGET_VERSION,
+        )
     if group_name:
-        eval_example.set_config(ruff_ignore=eval_example.config.ruff_ignore + ['F821'], line_length=LINE_LENGTH)
+        eval_example.set_config(
+            ruff_ignore=eval_example.config.ruff_ignore + ['F821'],
+            line_length=LINE_LENGTH,
+            target_version=TARGET_VERSION,
+        )
 
     if not lint_settings.startswith('skip'):
         if eval_example.update_examples:
@@ -107,7 +120,11 @@ def run_example(example: CodeExample, eval_example: EvalExample, mocker: Any) ->
         else:
             if example.in_py_file():
                 # Ignore isort as double newlines will cause it to fail, but we remove them in py files
-                eval_example.set_config(ruff_ignore=eval_example.config.ruff_ignore + ['I001'], line_length=LINE_LENGTH)
+                eval_example.set_config(
+                    ruff_ignore=eval_example.config.ruff_ignore + ['I001'],
+                    line_length=LINE_LENGTH,
+                    target_version=TARGET_VERSION,
+                )
             eval_example.lint(example)
 
     if test_settings.startswith('skip'):
@@ -142,6 +159,7 @@ def run_example(example: CodeExample, eval_example: EvalExample, mocker: Any) ->
         group_globals.set(group_name, d2)
 
 
+@pytest.mark.thread_unsafe
 @pytest.mark.filterwarnings('ignore:(parse_obj_as|schema_json_of|schema_of) is deprecated.*:DeprecationWarning')
 @pytest.mark.skipif(bool(skip_reason), reason=skip_reason or 'not skipping')
 @pytest.mark.parametrize('example', find_examples(str(SOURCES_ROOT), skip=sys.platform == 'win32'), ids=str)
@@ -165,6 +183,7 @@ def set_cwd():
         os.chdir(cwd)
 
 
+@pytest.mark.thread_unsafe
 @pytest.mark.filterwarnings('ignore:(parse_obj_as|schema_json_of|schema_of) is deprecated.*:DeprecationWarning')
 @pytest.mark.skipif(bool(skip_reason), reason=skip_reason or 'not skipping')
 @pytest.mark.parametrize('example', find_examples(str(DOCS_ROOT), skip=sys.platform == 'win32'), ids=str)
@@ -183,14 +202,16 @@ def test_docs_examples(example: CodeExample, eval_example: EvalExample, tmp_path
     run_example(example, eval_example, mocker)
 
 
+@pytest.mark.thread_unsafe
 @pytest.mark.skipif(bool(skip_reason), reason=skip_reason or 'not skipping')
+@pytest.mark.skipif(sys.version_info >= (3, 13), reason='python-devtools does not yet support python 3.13')
 @pytest.mark.parametrize(
     'example', find_examples(str(DOCS_ROOT / 'integrations/devtools.md'), skip=sys.platform == 'win32'), ids=str
 )
 def test_docs_devtools_example(example: CodeExample, eval_example: EvalExample, tmp_path: Path):
     from ansi2html import Ansi2HTMLConverter
 
-    eval_example.set_config(ruff_ignore=['D', 'T'], line_length=LINE_LENGTH)
+    eval_example.set_config(ruff_ignore=['D', 'T', 'B', 'C4'], line_length=LINE_LENGTH, target_version=TARGET_VERSION)
 
     if eval_example.update_examples:
         eval_example.format(example)
